==> lb_branch_hours_blocks-1.0.1.tar.gz: lb_branch_hours_blocks/assets/js/hours_today.js <==
/**
 * Behaviors for the 'Today's hours' and 'More hours' functionality.
 */
(function ($, Drupal){
    Drupal.behaviors.today_hours = {
        /**
         * Used to track the setInveral.
         */
        refreshTimer: false,

        /**
         * @returns {string}
         */
        getDayOfWeek: function (tz) {
            // ISO day of week. returns a number of day of week from 1 to 7.
            return moment().tz(tz).format('E');
        },

        /**
         * @returns {string}
         */
        getDate: function (tz) {
            return moment().tz(tz).format('YYYY-MM-DD');
        },

        /**
         * Primary method for updating the today hours.
         */
        updateTodayHours: function () {
            if (typeof drupalSettings.lb_branch_hours_blocks === 'undefined') {
                drupalSettings.lb_branch_hours_blocks = {};
            }

            var $todayHours = $('.today-hours > .today');
            var hoursData = [];
            var branchHours = drupalSettings.lb_branch_hours_blocks.branch_hours || [];
            var tz = drupalSettings.lb_branch_hours_blocks.tz || 'America/New York';
            tz = tz.replace(/ /g,"_");
            var keys = drupalSettings.lb_branch_hours_blocks.keys || ['branch_hours', 'center_hours', 'open_hours', 'before_school_enrichment'];
            // Prioritize these arbitrary hours names first.
            keys.reverse().forEach(function (name) {
                if (typeof branchHours[name] != 'undefined') {
                    hoursData = branchHours[name];
                }
            });
            // Fallback to the first set of hours then.
            if (!hoursData.length && branchHours.length) {
                hoursData = branchHours.slice(0, 1);
            }

            if (hoursData.length) {
                var todayString = Drupal.behaviors.today_hours.getDate(tz);
                var dayOfWeek = Drupal.behaviors.today_hours.getDayOfWeek(tz);
                // got a value from 1..7, but in array keys 0..6
                dayOfWeek--;
                var hours = hoursData;
                var exceptions = []; // Holidays and other day exceptions will come later.

                if (typeof exceptions[todayString] != 'undefined') {
                    $todayHours.text(exceptions[todayString]);
                }
                else {
                    $todayHours.text(hours[dayOfWeek]);
                }
            }
        },

        /**
         * Drupal behavior attach.
         *
         * @param context
         * @param settings
         */
        attach: function (context, settings) {

            var $todayHours = $('.today-hours > .today');
            var onceClass = 'refresh-interval-set';

            // Bail out if there's already refresh action set.
            if (!$todayHours.hasClass(onceClass)) {

                // This will ensure that if people leave the tab open or the page comes back
                // into memory on a phone the hour will always be correct.
                this.refreshTimer = setInterval(this.updateTodayHours, 60 * 1000);

                // Run for the first time.
                this.updateTodayHours();
                $todayHours.addClass(onceClass);
            }
        }

    };
    Drupal.behaviors.more_hours = {
        attach: function (context, settings) {
            $('.more-hours', context).click(function (e){
                e.preventDefault();
                $('.branch-hours-dropdown').show();
            })
            $('.branch-hours-dropdown .close', context).click(function (e){
                e.preventDefault();
                $('.branch-hours-dropdown').hide();
            })
        }
    }
})(jQuery, Drupal);

==> lb_branch_hours_blocks-1.0.10.tar.gz: lb_branch_hours_blocks/assets/js/hours_today.js <==
/**
 * Behaviors for the 'Today's hours' and 'More hours' functionality.
 */
(function ($, Drupal){
    Drupal.behaviors.today_hours = {
        /**
         * Used to track the setInveral.
         */
        refreshTimer: false,

        /**
         * @returns {string}
         */
        getDayOfWeek: function (tz) {
            // ISO day of week. returns a string of day of week, e.g. Mon, Tue, etc.
            return moment().tz(tz).format('DDD');
        },

        /**
         * @returns {string}
         */
        getDate: function (tz) {
            return moment().tz(tz).format('YYYY-MM-DD');
        },

        /**
         * Primary method for updating the today hours.
         */
        updateTodayHours: function () {
            if (typeof drupalSettings.lb_branch_hours_blocks === 'undefined') {
                drupalSettings.lb_branch_hours_blocks = {};
            }

            var $todayHours = $('.hours .today');
            var hoursData = drupalSettings.lb_branch_hours_blocks.branch_hours || {};
            var tz = drupalSettings.lb_branch_hours_blocks.tz || 'America/New York';
            tz = tz.replace(/ /g,"_");

            if (Object.keys(hoursData).length) {
                var todayString = Drupal.behaviors.today_hours.getDate(tz);
                var dayOfWeek = Drupal.behaviors.today_hours.getDayOfWeek(tz);
                var exceptions = drupalSettings.lb_branch_hours_blocks.exceptions; // Holidays and other day exceptions will come later.

                if (typeof exceptions[todayString] != 'undefined') {
                    $todayHours.html(exceptions[todayString]);
                }
                else {
                    $todayHours.html(hoursData[dayOfWeek]);
                }
            }
        },

        /**
         * Drupal behavior attach.
         *
         * @param context
         * @param settings
         */
        attach: function (context, settings) {

            var $todayHours = $('.hours .today');
            var onceClass = 'refresh-interval-set';

            // Bail out if there's already refresh action set.
            if (!$todayHours.hasClass(onceClass)) {

                // This will ensure that if people leave the tab open or the page comes back
                // into memory on a phone the hour will always be correct.
                this.refreshTimer = setInterval(this.updateTodayHours, 60 * 1000);

                // Run for the first time.
                this.updateTodayHours();
                $todayHours.addClass(onceClass);
            }
        }

    };
    Drupal.behaviors.more_hours = {
        attach: function (context, settings) {
            $('.more-hours', context).click(function (e){
                e.preventDefault();
                $('.branch-hours-dropdown').show();
            })
            $('.branch-hours-dropdown .close', context).click(function (e){
                e.preventDefault();
                $('.branch-hours-dropdown').hide();
            })
        }
    }
})(jQuery, Drupal);
